@@ -70,7 +70,7 @@ class DivisionsHandler:
     def to_dict(self) -> dict:
         result = {}
         if len(self._divs) > 0:
-            result["D"] = {k.__str__(): SimpleSource.to_serialized(v) for k, v in self._divs.items()}
+            result["D"] = {k.to_serialized(): SimpleSource.to_serialized(v) for k, v in self._divs.items()}
         return result
 
     def __str__(self):
