@@ -7,6 +7,7 @@ from slapp_py.core_classes.clan_tag import ClanTag
 from slapp_py.core_classes.division import Division
 from slapp_py.core_classes.divisions_handler import DivisionsHandler
 from slapp_py.core_classes.name import Name
+from slapp_py.core_classes.simple_source import SimpleSource
 from slapp_py.core_classes.socials.battlefy_team_social import BattlefyTeamSocial
 from slapp_py.core_classes.socials.twitter import Twitter
 from slapp_py.helpers.dict_helper import from_list, to_list
@@ -99,6 +100,16 @@ class Team:
         else:
             return ' ⬅ '.join([d.__str__() for d in self.division_information.get_divs_unordered()[:3]])
 
+    def filter_to_source(self, source_id: SimpleSource) -> 'Team':
+        """Filter this Player instance down to the components made by a sources id."""
+        return Team(
+            battlefy_persistent_team_ids=[name for name in self.battlefy_persistent_team_ids if source_id in name.sources],
+            clan_tags=[name for name in self.clan_tags if source_id in name.sources],
+            division_information=self.division_information.filter_to_source(source_id),
+            names=[name for name in self.names if source_id in name.sources],
+            twitter_profiles=[name for name in self.twitter_profiles if source_id in name.sources],
+            guid=uuid4())
+
     @property
     def sources(self):
         return \
