@@ -61,7 +61,8 @@ def full_rebuild(skip_pauses: bool = False, patch: bool = True):
 if __name__ == '__main__':
     dotenv.load_dotenv()
     logging.basicConfig(level=logging.DEBUG)
+    logging.getLogger().setLevel("DEBUG")
 
-    # full_rebuild(skip_pauses=True, patch=True)
-    update_sources_with_placements()
-    update_sources_with_skills(clear_current_skills=True)
+    full_rebuild(skip_pauses=True, patch=False)
+    # update_sources_with_placements()
+    # update_sources_with_skills(clear_current_skills=True)
